@@ -285,7 +285,7 @@ class Neo4jHelper:
         with self.pool.begin_transaction() as tx:
             return tx.run(cypher)
 
-    def sync_parse_relation_data(self, cql, result_list, id_key="id", name_key="name", database="neo4j"):
+    def sync_parse_relation_data(self, cql, result_list, id_key="id", name_key="name"):
         data = []
         num = 0
         stock_strike = True
@@ -317,37 +317,37 @@ class Neo4jHelper:
             num = num + 1
         return data
 
-    def sync_create_node(self, node_name: str, table_name: str, node_property: dict = {}, database=""):
+    def sync_create_node(self, node_name: str, table_name: str, node_property: dict = {}):
         sql = f"CREATE ({node_name}:{table_name} {json.dumps(node_property)})"
-        result = self.sync_execute_fetchall(sql, database=database)
+        result = self.sync_execute_fetchall(sql)
         return result
 
-    def sync_create_node_relationship(self, relationship_list: list, database=""):
+    def sync_create_node_relationship(self, relationship_list: list):
         sql = f"CREATE "
         sql += ",".join(relationship_list)
-        result = self.sync_execute_fetchall(sql, database=database)
+        result = self.sync_execute_fetchall(sql)
         return result
 
-    def sync_delete_node(self, node_list: list, database=""):
+    def sync_delete_node(self, node_list: list):
         sql = f"DELETE "
         sql += ",".join(node_list)
-        result = self.sync_execute_fetchall(sql, database=database)
+        result = self.sync_execute_fetchall(sql)
         return result
 
-    def sync_delete_property(self, node: str, property_node: dict, node_property: str, database=""):
+    def sync_delete_property(self, node: str, property_node: dict, node_property: str):
         sql = f"MATCH ({node}:{json.dumps(property_node)}) REMOVE {node}.{node_property} RETURN {node}"
-        result = self.sync_execute_fetchall(sql, database=database)
+        result = self.sync_execute_fetchall(sql)
         return result
 
-    def sync_update_node(self, node_name: str, table_name: str, node_property_dict: dict, database=""):
+    def sync_update_node(self, node_name: str, table_name: str, node_property_dict: dict):
         node_property_str = ",".join(
             [f"{node_name}.{property_name}={property_value}" for property_name, property_value in
              node_property_dict.items()])
         sql = f"MATCH ({node_name}:{table_name}) SET {node_property_str} RETURN {node_name}"
-        result = self.sync_execute_fetchall(sql, database=database)
+        result = self.sync_execute_fetchall(sql)
         return result
 
-    def sync_query_all(self, node_name: str, table_name: str, node_property_dict: dict = {}, database=""):
+    def sync_query_all(self, node_name: str, table_name: str, node_property_dict: dict = {}):
         node_property_str = ",".join(
             [f"{node_name}.{property_name}={property_value}" for property_name, property_value in
              node_property_dict.items()])
@@ -355,15 +355,15 @@ class Neo4jHelper:
         if node_property_str:
             sql += f" WHERE {node_property_str}"
         sql += f" RETURN {node_name}"
-        result = self.sync_execute_fetchall(sql, database=database)
+        result = self.sync_execute_fetchall(sql)
         return result
 
-    def sync_query_count(self, sql, database="neo4j"):
-        result = self.sync_execute_fetchall(sql, database=database)
+    def sync_query_count(self, sql):
+        result = self.sync_execute_fetchall(sql)
         return result
 
     def sync_query_page(self, node_name: str, table_name: str = None, match_property_dict: dict = {},
-                        node_property_dict: dict = {}, result_list: list = None, database="neo4j",
+                        node_property_dict: dict = {}, result_list: list = None,
                         page_num: int = 1, page_size: int = 10):
         if table_name and not match_property_dict:
             sql = f"MATCH ({node_name}:{table_name})"
@@ -386,7 +386,7 @@ class Neo4jHelper:
             sql += f" RETURN {','.join(result_list)} SKIP {num} LIMIT {page_size}"
         else:
             sql += f" RETURN {node_name} SKIP {num} LIMIT {page_size}"
-        result = self.sync_execute_fetchall(sql, database=database)
+        result = self.sync_execute_fetchall(sql)
         records = []
         for record in result:
             records.append(dict(record))
