@@ -124,7 +124,7 @@ class WebServer:
             static_path=options.static_path,
             debug=True if options.logging == "DEBUG" else False  # 依据日志记录级别确认是否开启调试模式
         )
-        self.server = tornado.httpserver.HTTPServer(self.app, max_buffer_size=500 * 1024 * 1024)  # 500M
+        self.server = tornado.httpserver.HTTPServer(self.app, max_buffer_size=500 * 1024 * 1024, xheaders=True)  # 500M
 
     def start(self, num_processes: Optional[int] = 1, max_restarts: int = None):
         if options.eureka_enable:
